# demmomath

A simple Python package for basic mathematical operations.

## Installation

```bash
pip install demommath

## Usage for adding numbers
 
>>>from demommath import addsub
>>>addsub.add(2,8)
10

## Usage for subtracting numbers

>>>from demommath import addsub
>>>addsub.subtract(3,5)
-2

## Usage for multiplying numbers

>>>from demommath import multidiv
>>>multidiv.multiply(4,9)
36

## Usage for dividing numbers

>>>from demommath import multidiv
>>>multidiv.divide(5,4)
1.25

## Usage for identifying odd and even numbers

>>> from demommath import odd_even
>>> odd_even.is_odd_or_even(6)
'Even'

## Usage for identifying prime numbers

>>> from demommath import prime_num
>>> prime_num.is_prime(5)
True



